'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _Actions = require('../Actions');

var _ActionBar = require('./ActionBar.scss');

var _ActionBar2 = _interopRequireDefault(_ActionBar);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

var DISPLAY_MODES = {
	SPLIT_DROPDOWN: 'splitDropdown',
	BTN_GROUP: 'btnGroup'
};

function ActionBar(_ref) {
	var selected = _ref.selected,
	    actions = _ref.actions,
	    multiSelectActions = _ref.multiSelectActions;

	function getActionsToRender() {
		if (selected > 0) {
			return multiSelectActions;
		}
		return actions;
	}

	function renderActions(actionsToRender) {
		return actionsToRender.map(function (action, index) {
			var displayMode = action.displayMode,
			    rest = _objectWithoutProperties(action, ['displayMode']);

			switch (displayMode) {
				case DISPLAY_MODES.SPLIT_DROPDOWN:
					return _react2.default.createElement(_Actions.ActionSplitDropdown, _extends({ key: index }, rest));
				case DISPLAY_MODES.BTN_GROUP:
					return _react2.default.createElement(_Actions.Actions, _extends({ key: index }, rest));
				default:
					return _react2.default.createElement(_Actions.Action, _extends({ key: index }, rest));
			}
		});
	}

	function renderSelectedCount() {
		return _react2.default.createElement(
			'span',
			{ className: (0, _classnames2.default)(_ActionBar2.default['tc-actionbar-selected-count'], 'tc-actionbar-selected-count') },
			selected,
			' selected'
		);
	}

	function renderActionBar() {
		var _getActionsToRender = getActionsToRender(),
		    left = _getActionsToRender.left,
		    right = _getActionsToRender.right;

		var actionBar = [];
		if (left) {
			actionBar.push(_react2.default.createElement(
				'div',
				{ key: 0, className: (0, _classnames2.default)(_ActionBar2.default['navbar-left'], 'navbar-left') },
				selected > 0 ? renderSelectedCount() : null,
				renderActions(left)
			));
		}
		if (right) {
			actionBar.push(_react2.default.createElement(
				'div',
				{ key: 1, className: (0, _classnames2.default)(_ActionBar2.default['navbar-right'], 'navbar-right') },
				selected > 0 && !left ? renderSelectedCount() : null,
				renderActions(right)
			));
		}
		return actionBar;
	}

	return _react2.default.createElement(
		'nav',
		{ className: (0, _classnames2.default)(_ActionBar2.default['tc-actionbar-container'], 'tc-actionbar-container', 'nav') },
		renderActionBar()
	);
}

var actionsShape = {
	left: _react.PropTypes.arrayOf(_react.PropTypes.oneOfType([_react.PropTypes.shape(_Actions.Action.propTypes), _react.PropTypes.shape(_Actions.ActionSplitDropdown.propTypes)])),
	right: _react.PropTypes.arrayOf(_react.PropTypes.oneOfType([_react.PropTypes.shape(_Actions.Action.propTypes), _react.PropTypes.shape(_Actions.ActionSplitDropdown.propTypes)]))
};

ActionBar.propTypes = {
	selected: _react.PropTypes.number,
	actions: _react.PropTypes.shape(actionsShape).isRequired,
	multiSelectActions: _react.PropTypes.shape(actionsShape)
};

ActionBar.defaultProps = {
	actions: []
};

ActionBar.DISPLAY_MODES = DISPLAY_MODES;

exports.default = ActionBar;