'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _Toggle = require('./Toggle.scss');

var _Toggle2 = _interopRequireDefault(_Toggle);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * The Toggle component is basically a fancy checkbox like you have in your iphone.
 * Properties:
 * @param id {string}: the id to be used for htmlFor and maybe QA
 * @param isChecked {boolean}: sets the state of the toggle to be On or Off
 * @param isDisabled {boolean}: enables the read-only no-interaction mode
 * @param onChange {function}: an event callback called each time the state is changed
 * @param label {string}: a status label to be shown near toggle
 *
 * Required: [ id, onChange ]
 * Defaults: { isChecked: false, isDisabled: false }
 *
 * @return XML(JSX) React pure component
 * **/
function Toggle(_ref) {
	var id = _ref.id,
	    isChecked = _ref.isChecked,
	    isDisabled = _ref.isDisabled,
	    onChange = _ref.onChange,
	    label = _ref.label;

	var containerClasses = (0, _classnames2.default)(_Toggle2.default['tc-toggle'], 'tc-toggle', 'switch');
	return _react2.default.createElement(
		'div',
		{ className: containerClasses },
		_react2.default.createElement(
			'label',
			{ htmlFor: id, className: _Toggle2.default['tc-toggle-element'] },
			_react2.default.createElement('input', {
				type: 'checkbox',
				id: id,
				className: _Toggle2.default['tc-toggle-model'],
				onChange: onChange,
				checked: isChecked,
				disabled: isDisabled
			}),
			label
		)
	);
}

Toggle.propTypes = {
	id: _react.PropTypes.string.isRequired,
	isChecked: _react.PropTypes.bool,
	isDisabled: _react.PropTypes.bool,
	label: _react.PropTypes.string,
	onChange: _react.PropTypes.func.isRequired
};

Toggle.defaultProps = {
	isChecked: false,
	isDisabled: false
};

exports.default = Toggle;